@@ -4,7 +4,7 @@ import asyncio
 import functools
 
 from sentry_sdk._compat import iteritems
-from sentry_sdk._types import MYPY
+from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.consts import OP
 from sentry_sdk.hub import Hub, _should_send_default_pii
 from sentry_sdk.integrations import DidNotEnable, Integration
@@ -21,7 +21,7 @@ from sentry_sdk.utils import (
     transaction_from_function,
 )
 
-if MYPY:
+if TYPE_CHECKING:
     from typing import Any, Awaitable, Callable, Dict, Optional
 
     from sentry_sdk.scope import Scope as SentryScope
@@ -183,7 +183,9 @@ def patch_exception_middleware(middleware_class):
                 exp = args[0]
 
                 is_http_server_error = (
-                    hasattr(exp, "status_code") and exp.status_code >= 500
+                    hasattr(exp, "status_code")
+                    and isinstance(exp.status_code, int)
+                    and exp.status_code >= 500
                 )
                 if is_http_server_error:
                     _capture_exception(exp, handled=True)
